@@ -138,14 +138,14 @@ static void get_mouse_values(int *accel_return, int *denom_return, int *thresh_r
 
 static void set_mouse_values(gboolean right_handed, int accel, int threshold)
 {
-    unsigned char map[5] = { '\0','\0','\0','\0','\0' };
+    unsigned char map[7] = { '\0','\0','\0','\0','\0','\0','\0' };
     unsigned int buttons = 0;
 
     gdk_flush();
     gdk_error_trap_push();
 
     XChangePointerControl(GDK_DISPLAY(), True, True, accel, denominator, threshold);
-    buttons = XGetPointerMapping(GDK_DISPLAY(), map, 5);
+    buttons = XGetPointerMapping(GDK_DISPLAY(), map, 7);
 
     if(right_handed)
     {
